@@ -3,7 +3,7 @@ import tensorflow.keras.backend as K
 import tensorflow.keras as ks
 import tensorflow.keras.layers as layers
 import medgeconv
-from orcanet.utilities.misc import get_register
+from orcanet.misc import get_register
 
 # for loading via toml and orcanet custom objects
 blocks, register = get_register()
@@ -566,6 +566,8 @@ class OutputReg:
                  **kwargs):
         self.output_neurons = output_neurons
         self.output_name = output_name
+        if isinstance(unit_list, int):
+            unit_list = (unit_list, )
         self.unit_list = unit_list
         self.transition = transition
         self.kwargs = kwargs
@@ -603,7 +605,7 @@ class OutputRegNormal:
     sigma_activation : str, optional
         Activation function for the sigma neurons.
 
-    See OutputReg for other paramters.
+    See OutputReg for other parameters.
 
     """
     def __init__(self, output_neurons,
@@ -615,6 +617,8 @@ class OutputRegNormal:
                  **kwargs):
         self.output_neurons = output_neurons
         self.output_name = output_name
+        if isinstance(unit_list, int):
+            unit_list = (unit_list, )
         self.unit_list = unit_list
         self.mu_activation = mu_activation
         self.sigma_activation = sigma_activation
@@ -644,6 +648,70 @@ class OutputRegNormal:
             [tf.expand_dims(tsr, -2) for tsr in [mu, sigma]])
 
 
+@register
+class OutputRegNormalSplit(OutputRegNormal):
+    """
+    Output block for regression using a normal distribution as output.
+
+    The sigma will be produced by its own tower of dense layers that
+    is seperated from the rest of the network via gradient stop.
+
+    The output is a list with two tensors:
+    - The first is the mu with shape (?, output_neurons) and name output_name.
+    - The second is mu + sigma with shape (?, 2, output_neurons),
+      with [:, 0] being the mu and [:, 1] being the sigma.
+      Its name is output_name + '_err'.
+
+    Parameters
+    ----------
+    sigma_unit_list : List, optional
+        A list of ints. Neurons in the Dense layers for the tower that
+        outputs the sigma. E.g., [64, 32] would add
+        two Dense layers, the first with 64 neurons, the second with
+        32 neurons.
+        Default: Same as unit_list.
+
+    See OutputRegNormal for other parameters.
+
+    """
+    def __init__(self, *args, sigma_unit_list=None, **kwargs):
+        super().__init__(*args, **kwargs)
+        if sigma_unit_list is None:
+            sigma_unit_list = self.unit_list
+        self.sigma_unit_list = sigma_unit_list
+
+    def __call__(self, layer):
+        if self.transition:
+            x_base = getattr(layers, self.transition.split("keras:")[-1])()(layer)
+        else:
+            x_base = layer
+
+        x = x_base
+        if self.unit_list is not None:
+            for units in self.unit_list:
+                x = DenseBlock(units=units, **self.kwargs)(x)
+        mu = layers.Dense(
+            units=self.output_neurons,
+            activation=self.mu_activation,
+            name=self.output_name)(x)
+
+        # Network for the errors of the labels
+        x = ks.backend.stop_gradient(x_base)
+        if self.sigma_unit_list is not None:
+            for units in self.sigma_unit_list:
+                x = DenseBlock(units=units, **self.kwargs)(x)
+        sigma = layers.Dense(
+            units=self.output_neurons,
+            activation=self.sigma_activation,
+            name=f"{self.output_name}_sigma")(x)
+
+        mu_stopped = ks.backend.stop_gradient(mu)
+        err_output = layers.Concatenate(name=f"{self.output_name}_err", axis=-2)(
+            [tf.expand_dims(tsr, -2) for tsr in [mu_stopped, sigma]])
+
+        return [mu, err_output]
+
+
 @register
 class OutputCateg:
     """
@@ -717,6 +785,7 @@ class OutputRegErr:
         Keywords for the dense blocks.
 
     """
+    # TODO deprecated, only here for historcal reasons
     def __init__(self, output_names, flatten=True, **kwargs):
         self.flatten = flatten
         self.output_names = output_names
