@@ -9,7 +9,9 @@ import shutil
 import h5py
 import numpy as np
 from inspect import signature
-from orcanet.h5_generator import Hdf5BatchGenerator
+
+# moved into IOHandler.get_batch for speed up; tensorflow import is slow!
+# from orcanet.h5_generator import Hdf5BatchGenerator
 
 
 def get_subfolder(main_folder, name=None, create=False):
@@ -323,82 +325,6 @@ class IOHandler(object):
         pred_files_list.sort()  # sort predicted val files from 1 ... n
         return pred_files_list
 
-    @staticmethod
-    def get_cumulative_number_of_rows(file_list):
-        """
-        Returns the cumulative number of rows (axis_0) in a list
-        based on the specified input .h5 files.
-
-        The folders in each file are expected to have the same number of rows,
-        such that the info can be taken from the first folder.
-
-        Parameters
-        ----------
-        file_list : list
-            List that contains the filepaths of the h5 files.
-
-        Returns
-        -------
-        cum_number_of_rows : List
-            List that contains the cumulative number of rows (i.e. [0,100,200,300,...] if each file has 100 rows).
-
-        """
-        total_number_of_rows = 0
-        cum_number_of_rows = [0]
-
-        for file_name in file_list:
-            f = h5py.File(file_name, 'r')
-
-            # get number of rows from the first folder of the file -> each folder needs to have the same number of rows
-            f_keys = list(f.keys())
-            total_number_of_rows += f[f_keys[0]].shape[0]
-            cum_number_of_rows.append(total_number_of_rows)
-
-            f.close()
-
-        return cum_number_of_rows
-
-    def concatenate_pred_files(self, concatenated_folder):
-        """ Concatenates prediction files to a single one. """
-        if not os.path.isdir(concatenated_folder):
-            os.mkdir(concatenated_folder)
-
-        pred_files_list = self.get_pred_files_list()
-
-        # get cumulative number of rows in the pred files
-        cum_number_of_rows = self.get_cumulative_number_of_rows(pred_files_list)
-
-        basename = os.path.basename(pred_files_list[-1])  # take one pred filepath, doesnt matter which one so use -1
-        pred_filepath_conc = concatenated_folder + '/' + basename.split('_val_file_')[0] + '_all_val_files.h5'
-
-        f_conc = h5py.File(pred_filepath_conc, 'w')
-        for i, pred_file in enumerate(pred_files_list):
-            print('Concatenating file ' + str(i) + ' of ' + str(len(pred_files_list)))
-
-            f = h5py.File(pred_file, 'r')
-            for folder_name in f:
-                folder_data = f[folder_name]
-
-                if i == 0:
-                    # first file; create the dataset with no max shape
-                    maxshape = (None,) + folder_data.shape[1:]  # change shape of axis zero to None
-                    chunks = True
-                    compression, compression_opts = folder_data.compression, folder_data.compression_opts
-
-                    output_dataset = f_conc.create_dataset(folder_name, data=folder_data, maxshape=maxshape, chunks=chunks,
-                                                           compression=compression, compression_opts=compression_opts)
-
-                    output_dataset.resize(cum_number_of_rows[-1], axis=0)
-
-                else:
-                    f_conc[folder_name][cum_number_of_rows[i]:cum_number_of_rows[i + 1]] = folder_data
-
-            f_conc.flush()
-
-        f_conc.close()
-
-        return pred_filepath_conc
-
     def get_local_files(self, which):
         """
         Get the training or validation file paths for each list input set.
@@ -689,6 +615,9 @@ class IOHandler(object):
                 From the y_values datagroup of the input files.
 
         """
+        # this will import tf; move inside here for speed up
+        from orcanet.h5_generator import Hdf5BatchGenerator
+
         gen = Hdf5BatchGenerator(
             next(self.yield_files("train")),
             batchsize=self.cfg.batchsize,
